@@ -1,7 +1,8 @@
 package MARC::Moose::Formater::Iso2709;
 # ABSTRACT: MARC::Moose record formater into ISO 2709 format
-$MARC::Moose::Formater::Iso2709::VERSION = '1.0.38';
+$MARC::Moose::Formater::Iso2709::VERSION = '1.0.39';
 use Moose;
+use utf8;
 use Modern::Perl;
 
 extends 'MARC::Moose::Formater';
@@ -30,8 +31,8 @@ override 'format' => sub {
         #utf8::encode($str) unless utf8::is_utf8($str);
         $fields .= $str;
         #FIXME: Which of this lines is the correct one?
-        #my $len = bytes::length($str);
-        my $len = length($str);
+        my $len = bytes::length($str);
+        #my $len = length($str);
         $directory .= sprintf( "%03s%04d%05d", $field->tag, $len, $from );
         $from += $len;
     }
@@ -61,7 +62,7 @@ MARC::Moose::Formater::Iso2709 - MARC::Moose record formater into ISO 2709 forma
 
 =head1 VERSION
 
-version 1.0.38
+version 1.0.39
 
 =head1 AUTHOR
 
@@ -69,7 +70,7 @@ Frédéric Demians <f.demians@tamil.fr>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Frédéric Demians.
+This software is copyright (c) 2019 by Frédéric Demians.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
